==> haskell-trifecta-2.1.1-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-trifecta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 trifecta
version:              2.1.1
visibility:           public
id:                   trifecta-2.1.1-F7YYW1XkL5SKxI6nC5ZMkE
key:                  trifecta-2.1.1-F7YYW1XkL5SKxI6nC5ZMkE
license:              BSD-3-Clause
copyright:            Copyright (C) 2010-2017 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/trifecta/
synopsis:
    A modern parser combinator library with convenient diagnostics

description:
    A modern parser combinator library with slicing and Clang-style colored diagnostics

    For example:

    <<https://i.imgur.com/ZyzUSSn.png>>

    <images/example.png (Local Copy)>

category:             Text, Parsing, Diagnostics, Pretty Printer, Logging
abi:                  a83c7535f4e8f34d0fa96b29b5008d2d
exposed:              True
exposed-modules:
    Text.Trifecta Text.Trifecta.Combinators Text.Trifecta.Delta
    Text.Trifecta.Highlight Text.Trifecta.Parser
    Text.Trifecta.Rendering Text.Trifecta.Result Text.Trifecta.Rope
    Text.Trifecta.Tutorial Text.Trifecta.Util.IntervalMap
    Text.Trifecta.Util.It

hidden-modules:
    Text.Trifecta.Util.Combinators Text.Trifecta.Util.Pretty

import-dirs:          /usr/lib/ghc-8.10.4/site-local/trifecta-2.1.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/trifecta-2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/trifecta-2.1.1
hs-libraries:         HStrifecta-2.1.1-F7YYW1XkL5SKxI6nC5ZMkE
depends:
    ansi-terminal-0.11-LgP8qDXSNhY9o8ci2eucZ9 array-0.5.4.0
    base-4.14.1.0 blaze-builder-0.4.2.1-KRXf5d4GbjLDdq3vlVdrGQ
    blaze-html-0.9.1.2-8AVwqYCv0g69174rM0iTyA
    blaze-markup-0.8.2.8-HppPMYfwLLe8Yml18fREGi bytestring-0.10.12.0
    charset-0.3.8-62jBTchsvcy8PbQSAcUxL2
    comonad-5.0.8-EN0cWUvmryYHtrCrGXG2mR containers-0.6.2.1
    deepseq-1.4.4.0 fingertree-0.1.4.2-3gUHXwOEKwg4d64WHlt3Zp
    ghc-prim-0.6.1 hashable-1.3.1.0-1TzQw0rlraYH9EvMt0jxBh
    indexed-traversable-0.1.1-Dw8MIJyvCj8IZQDXOa8TBp
    lens-4.19.2-5oJlqA0CWaK9AA084Myatp mtl-2.2.2
    parsers-0.12.10-EhwOrmUyTle34wKB5m5M1P
    prettyprinter-1.7.0-KdSA2qQKKpoA1akakCjxAK
    prettyprinter-ansi-terminal-1.1.2-CrMWGWqxZ4q2f56S0NCHnB
    profunctors-5.6.2-N0awPHz8gV42wPtfoka2E
    reducers-3.12.3-1c0ALwMd7DcGa9U3yCt0FL transformers-0.5.6.2
    unordered-containers-0.2.13.0-HtLybBXdm0X81lurKYn063
    utf8-string-1.0.2-7pqBkplor7g1hjwTjVt3SV

haddock-interfaces:   /usr/share/doc/haskell-trifecta/html/trifecta.haddock
haddock-html:         /usr/share/doc/haskell-trifecta/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-trifecta-2.1.1-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-trifecta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 trifecta
version:              2.1.1
visibility:           public
id:                   trifecta-2.1.1-LQ8t8pTy9OyEftojE0iHym
key:                  trifecta-2.1.1-LQ8t8pTy9OyEftojE0iHym
license:              BSD-3-Clause
copyright:            Copyright (C) 2010-2017 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/trifecta/
synopsis:
    A modern parser combinator library with convenient diagnostics

description:
    A modern parser combinator library with slicing and Clang-style colored diagnostics

    For example:

    <<https://i.imgur.com/ZyzUSSn.png>>

    <images/example.png (Local Copy)>

category:             Text, Parsing, Diagnostics, Pretty Printer, Logging
abi:                  b9cbb4a8d017c1e315f61ffff0635b93
exposed:              True
exposed-modules:
    Text.Trifecta Text.Trifecta.Combinators Text.Trifecta.Delta
    Text.Trifecta.Highlight Text.Trifecta.Parser
    Text.Trifecta.Rendering Text.Trifecta.Result Text.Trifecta.Rope
    Text.Trifecta.Tutorial Text.Trifecta.Util.IntervalMap
    Text.Trifecta.Util.It

hidden-modules:
    Text.Trifecta.Util.Combinators Text.Trifecta.Util.Pretty

import-dirs:          /usr/lib/ghc-8.10.4/site-local/trifecta-2.1.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/trifecta-2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/trifecta-2.1.1
hs-libraries:         HStrifecta-2.1.1-LQ8t8pTy9OyEftojE0iHym
depends:
    ansi-terminal-0.11-B33URfqMvdcAXWIdsUyVZE array-0.5.4.0
    base-4.14.1.0 blaze-builder-0.4.2.1-KRXf5d4GbjLDdq3vlVdrGQ
    blaze-html-0.9.1.2-Cf7xPXICv5eFpaEyE5SWM5
    blaze-markup-0.8.2.8-ACVz1rfCPLh3fN75M0p3gt bytestring-0.10.12.0
    charset-0.3.8-DjCXRWE7772PgvvuAyJaS
    comonad-5.0.8-9zH6evksmCOCl8EiOWCZAq containers-0.6.2.1
    deepseq-1.4.4.0 fingertree-0.1.4.2-IOBxtAO6BeQ5W7Og7bMAyj
    ghc-prim-0.6.1 hashable-1.3.1.0-1TzQw0rlraYH9EvMt0jxBh
    indexed-traversable-0.1.1-Dw8MIJyvCj8IZQDXOa8TBp
    lens-4.19.2-5LM7AKOcCpz4NIuiuXiILR mtl-2.2.2
    parsers-0.12.10-1kyo42gSWoX20yMZCgBznT
    prettyprinter-1.7.0-GU9V05hbByOJsuRSv1KKWG
    prettyprinter-ansi-terminal-1.1.2-Lc9mkP2JZjD3Ok0nDPj9vX
    profunctors-5.6.2-GERPk2aKNhL7iEdQbm0u7N
    reducers-3.12.3-F18Gc7m8X5k3u1bbBaQAR6 transformers-0.5.6.2
    unordered-containers-0.2.13.0-I4USYXV3Fmg2LoeGz2Nrci
    utf8-string-1.0.2-7pqBkplor7g1hjwTjVt3SV

haddock-interfaces:   /usr/share/doc/haskell-trifecta/html/trifecta.haddock
haddock-html:         /usr/share/doc/haskell-trifecta/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
